var _a;
import { jsx, jsxs } from "react/jsx-runtime";
import { PassThrough } from "stream";
import { renderToPipeableStream } from "react-dom/server";
import { RemixServer, Meta, Links, Outlet, ScrollRestoration, Scripts, useLoaderData, Link, useFetcher, useNavigate, useActionData, Form, useRouteError } from "@remix-run/react";
import { createReadableStreamFromReadable, json, redirect } from "@remix-run/node";
import { isbot } from "isbot";
import "@shopify/shopify-app-remix/adapters/node";
import { shopifyApp, ApiVersion, AppDistribution, DeliveryMethod, LoginErrorType, boundary } from "@shopify/shopify-app-remix/server";
import { PrismaSessionStorage } from "@shopify/shopify-app-session-storage-prisma";
import { restResources } from "@shopify/shopify-api/rest/admin/2024-01";
import { PrismaClient } from "@prisma/client";
import { Page, Layout, Card, Text, BlockStack, Button, AppProvider, FormLayout, TextField } from "@shopify/polaris";
import mysql from "mysql2/promise";
import { useEffect, useCallback, useState } from "react";
import { AppProvider as AppProvider$1 } from "@shopify/shopify-app-remix/react";
const prisma = global.prisma || new PrismaClient();
if (process.env.NODE_ENV !== "production") {
  if (!global.prisma) {
    global.prisma = new PrismaClient();
  }
}
const shopify = shopifyApp({
  apiKey: process.env.SHOPIFY_API_KEY,
  apiSecretKey: process.env.SHOPIFY_API_SECRET || "",
  apiVersion: ApiVersion.April24,
  scopes: (_a = process.env.SCOPES) == null ? void 0 : _a.split(","),
  appUrl: process.env.SHOPIFY_APP_URL || "",
  authPathPrefix: "/auth",
  sessionStorage: new PrismaSessionStorage(prisma),
  distribution: AppDistribution.AppStore,
  restResources,
  webhooks: {
    APP_UNINSTALLED: {
      deliveryMethod: DeliveryMethod.Http,
      callbackUrl: "/webhooks"
    },
    APP_SUBSCRIPTIONS_UPDATE: {
      deliveryMethod: DeliveryMethod.Http,
      callbackUrl: "/webhooks"
    }
  },
  hooks: {
    afterAuth: async ({ session }) => {
      shopify.registerWebhooks({ session });
    }
  },
  future: {
    v3_webhookAdminContext: true,
    v3_authenticatePublic: true,
    v3_lineItemBilling: true,
    unstable_newEmbeddedAuthStrategy: true
  },
  ...process.env.SHOP_CUSTOM_DOMAIN ? { customShopDomains: [process.env.SHOP_CUSTOM_DOMAIN] } : {}
});
ApiVersion.April24;
const addDocumentResponseHeaders = shopify.addDocumentResponseHeaders;
const authenticate = shopify.authenticate;
shopify.unauthenticated;
const login = shopify.login;
shopify.registerWebhooks;
shopify.sessionStorage;
const ABORT_DELAY = 5e3;
async function handleRequest(request, responseStatusCode, responseHeaders, remixContext) {
  addDocumentResponseHeaders(request, responseHeaders);
  const userAgent = request.headers.get("user-agent");
  const callbackName = isbot(userAgent ?? "") ? "onAllReady" : "onShellReady";
  return new Promise((resolve, reject) => {
    const { pipe, abort } = renderToPipeableStream(
      /* @__PURE__ */ jsx(
        RemixServer,
        {
          context: remixContext,
          url: request.url,
          abortDelay: ABORT_DELAY
        }
      ),
      {
        [callbackName]: () => {
          const body = new PassThrough();
          const stream = createReadableStreamFromReadable(body);
          responseHeaders.set("Content-Type", "text/html");
          resolve(
            new Response(stream, {
              headers: responseHeaders,
              status: responseStatusCode
            })
          );
          pipe(body);
        },
        onShellError(error) {
          reject(error);
        },
        onError(error) {
          responseStatusCode = 500;
          console.error(error);
        }
      }
    );
    setTimeout(abort, ABORT_DELAY);
  });
}
const entryServer = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: handleRequest
}, Symbol.toStringTag, { value: "Module" }));
function App$2() {
  return /* @__PURE__ */ jsxs("html", { children: [
    /* @__PURE__ */ jsxs("head", { children: [
      /* @__PURE__ */ jsx("meta", { charSet: "utf-8" }),
      /* @__PURE__ */ jsx("meta", { name: "viewport", content: "width=device-width,initial-scale=1" }),
      /* @__PURE__ */ jsx("link", { rel: "preconnect", href: "https://cdn.shopify.com/" }),
      /* @__PURE__ */ jsx(
        "link",
        {
          rel: "stylesheet",
          href: "https://cdn.shopify.com/static/fonts/inter/v4/styles.css"
        }
      ),
      /* @__PURE__ */ jsx(Meta, {}),
      /* @__PURE__ */ jsx(Links, {})
    ] }),
    /* @__PURE__ */ jsxs("body", { children: [
      /* @__PURE__ */ jsx(Outlet, {}),
      /* @__PURE__ */ jsx(ScrollRestoration, {}),
      /* @__PURE__ */ jsx(Scripts, {})
    ] })
  ] });
}
const route0 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: App$2
}, Symbol.toStringTag, { value: "Module" }));
const pool = mysql.createPool({
  host: "localhost",
  user: "root",
  password: "",
  database: "section_store"
});
const query = async (sql, params) => {
  const [rows] = await pool.execute(sql, params);
  return rows;
};
const CREATE_ONE_TIME_CHARGE_MUTATION = `
  mutation AppPurchaseOneTimeCreate($name: String!, $price: MoneyInput!, $returnUrl: URL!, $test: Boolean) {
    appPurchaseOneTimeCreate(name: $name, returnUrl: $returnUrl, price: $price, test: $test) {
      userErrors {
        field
        message
      }
      appPurchaseOneTime {
        createdAt
        id
      }
      confirmationUrl
      
    }
  }
`;
const SET_METAFIELD_MUTATION = `
  mutation setMetafield($input: MetafieldsSetInput!) {
    metafieldsSet(metafields: [$input]) {
      metafields {
        id
        key
        value
      }
      userErrors {
        field
        message
      }
    }
  }
`;
async function getLayoutStatus(session, layoutName) {
  const currentShop = session.shop;
  const result = await query(
    "SELECT status FROM layouts WHERE layout_name = ? AND shop = ?",
    [layoutName, currentShop]
  );
  if (result.length === 0) {
    await query(
      "INSERT INTO layouts (layout_name, shop, status) VALUES (?, ?, ?)",
      [layoutName, currentShop, "inactive"]
    );
    return "inactive";
  }
  return result[0].status;
}
async function updateLayoutMetafield(session, layoutName, isActive) {
  const metafieldKey = `layout_${layoutName.toLowerCase().replace(/\s+/g, "_")}`;
  const appIdQuery = `
    query {
      currentAppInstallation {
        id
      }
    }
  `;
  const appIdResponse = await fetch(`https://${session.shop}/admin/api/2024-01/graphql.json`, {
    method: "POST",
    headers: {
      "Content-Type": "application/json",
      "X-Shopify-Access-Token": session.accessToken
    },
    body: JSON.stringify({ query: appIdQuery })
  });
  const appIdData = await appIdResponse.json();
  const appInstallationID = appIdData.data.currentAppInstallation.id;
  const requestBody = {
    query: SET_METAFIELD_MUTATION,
    variables: {
      input: {
        ownerId: appInstallationID,
        namespace: "custom_app",
        key: metafieldKey,
        value: JSON.stringify(isActive),
        type: "boolean"
      }
    }
  };
  const response = await fetch(`https://${session.shop}/admin/api/2024-01/graphql.json`, {
    method: "POST",
    headers: {
      "Content-Type": "application/json",
      "X-Shopify-Access-Token": session.accessToken
    },
    body: JSON.stringify(requestBody)
  });
  const data = await response.json();
  console.log(data);
  if (data.errors || data.data.metafieldsSet.userErrors && data.data.metafieldsSet.userErrors.length > 0) {
    throw new Error("Error updating metafield");
  }
  return true;
}
const VERIFY_CHARGE_QUERY = `
  query getAppPurchaseOneTime($id: ID!) {
    node(id: $id) {
      ... on AppPurchaseOneTime {
        status
        test
        name
        createdAt
      }
    }
  }
`;
async function verifyCharge(session, chargeId) {
  console.log("Verifying charge:", chargeId);
  const response = await fetch(`https://${session.shop}/admin/api/2024-01/graphql.json`, {
    method: "POST",
    headers: {
      "Content-Type": "application/json",
      "X-Shopify-Access-Token": session.accessToken
    },
    body: JSON.stringify({
      query: VERIFY_CHARGE_QUERY,
      variables: { id: chargeId }
    })
  });
  const data = await response.json();
  console.log("Charge verification response:", data);
  if (data.errors) {
    console.error("Verification errors:", data.errors);
    throw new Error("Error verifying charge");
  }
  if (!data.data.node) {
    console.error("No charge data found");
    throw new Error("Charge not found");
  }
  return data.data.node;
}
const createOneTimeCharge = async (session, name, price, returnUrl) => {
  console.log("Creating charge for:", name);
  const requestBody = {
    query: CREATE_ONE_TIME_CHARGE_MUTATION,
    variables: {
      name,
      price,
      returnUrl,
      test: true
    }
  };
  try {
    const response = await fetch(`https://${session.shop}/admin/api/2024-01/graphql.json`, {
      method: "POST",
      headers: {
        "Content-Type": "application/json",
        "X-Shopify-Access-Token": session.accessToken
      },
      body: JSON.stringify(requestBody)
    });
    const data = await response.json();
    console.log("Charge creation response:", data);
    if (data.errors || data.data.appPurchaseOneTimeCreate.userErrors && data.data.appPurchaseOneTimeCreate.userErrors.length > 0) {
      console.error("Charge creation errors:", data.errors || data.data.appPurchaseOneTimeCreate.userErrors);
      throw new Error("Error creating charge");
    }
    const { appPurchaseOneTimeCreate } = data.data;
    const chargeId = appPurchaseOneTimeCreate.appPurchaseOneTime.id;
    console.log("Generated charge ID:", chargeId);
    await query(
      "UPDATE layouts SET charge_id = ?, status = ? WHERE layout_name = ? AND shop = ?",
      [chargeId, "inactive", name, session.shop]
    );
    const confirmationUrl = new URL(appPurchaseOneTimeCreate.confirmationUrl);
    confirmationUrl.searchParams.append("charge_id", chargeId);
    return confirmationUrl.toString();
  } catch (error) {
    console.error("Error in createOneTimeCharge:", error);
    throw error;
  }
};
async function activateFreeLayout(session, layoutName) {
  try {
    await query(
      "UPDATE layouts SET status = ? WHERE layout_name = ? AND shop = ?",
      ["active", layoutName, session.shop]
    );
    await updateLayoutMetafield(session, layoutName, true);
    return { success: true, message: "Layout activated successfully" };
  } catch (error) {
    console.error("Error activating free layout:", error);
    return { success: false, message: "An error occurred while activating the layout." };
  }
}
async function deactivateLayout(session, layoutName) {
  try {
    await query(
      "UPDATE layouts SET status = ? WHERE layout_name = ? AND shop = ?",
      ["inactive", layoutName, session.shop]
    );
    await updateLayoutMetafield(session, layoutName, false);
    return { success: true, message: "Layout deactivated successfully" };
  } catch (error) {
    console.error("Error deactivating layout:", error);
    throw error;
  }
}
async function getAllLayoutStatuses(session) {
  const layouts = ["Layout 1", "Layout 2", "Layout 3", "Layout 4"];
  const statuses = {};
  for (const layout of layouts) {
    statuses[layout] = await getLayoutStatus(session, layout);
  }
  return statuses;
}
async function handleAppPurchaseWebhook(payload, shop) {
  const { appPurchaseOneTime } = payload;
  const { name, status, id: chargeId } = appPurchaseOneTime;
  if (status === "ACTIVE") {
    try {
      const session = await getSessionFromShop(shop);
      await query(
        "UPDATE layouts SET status = ? , charge_id = ?  WHERE layout_name = ? AND shop = ?",
        ["active", chargeId, name, shop]
      );
      await updateLayoutMetafield(session, name, true);
      console.log(`Payment approved for ${name} in shop ${shop}`);
    } catch (error) {
      console.error(`Error processing webhook for ${name} in shop ${shop}:`, error);
      throw error;
    }
  } else {
    console.log(`Payment not active for ${name} in shop ${shop}. Status: ${status}`);
  }
}
async function updateChargeStatus(session, chargeUrl) {
  console.log("Starting charge status update for URL:", chargeUrl);
  try {
    const chargeIdMatch = chargeUrl.match(/\/(\d+)$/);
    if (!chargeIdMatch) {
      console.error("No charge ID found in URL:", chargeUrl);
      return { success: false, message: "Invalid charge URL format" };
    }
    const chargeId = chargeIdMatch[1];
    console.log("Extracted charge ID:", chargeId);
    const chargeGid = `gid://shopify/AppPurchaseOneTime/${chargeId}`;
    console.log("Constructed charge GID:", chargeGid);
    const charge = await verifyCharge(session, chargeGid);
    console.log("Charge verification result:", charge);
    const layoutResult = await query(
      "SELECT layout_name FROM layouts WHERE charge_id = ? AND shop = ?",
      [chargeGid, session.shop]
    );
    if (layoutResult.length === 0) {
      console.error("No layout found for charge:", chargeGid);
      return { success: false, message: "Layout not found for this charge" };
    }
    const layoutName = layoutResult[0].layout_name;
    if (charge.status === "ACTIVE") {
      await query(
        "UPDATE layouts SET status = 'active' WHERE layout_name = ? AND shop = ?",
        [layoutName, session.shop]
      );
      await updateLayoutMetafield(session, layoutName, true);
      console.log("Successfully activated layout:", layoutName);
      return {
        success: true,
        message: `${layoutName} has been activated successfully!`,
        layoutName
      };
    } else if (charge.status === "PENDING") {
      console.log("Charge is still pending:", layoutName);
      return {
        success: false,
        message: "Your payment is still pending. Please complete the payment process.",
        layoutName
      };
    } else if (charge.status === "DECLINED") {
      await query(
        "UPDATE layouts SET status = 'inactive', charge_id = NULL WHERE charge_id = ? AND shop = ?",
        [chargeGid, session.shop]
      );
      console.log("Charge was declined for layout:", layoutName);
      return {
        success: false,
        message: "Payment was declined. Please try again.",
        layoutName
      };
    } else {
      console.log(`Unexpected charge status: ${charge.status} for layout:`, layoutName);
      return {
        success: false,
        message: `Unexpected payment status: ${charge.status}`,
        layoutName
      };
    }
  } catch (error) {
    console.error("Error in updateChargeStatus:", error);
    throw error;
  }
}
const loader$7 = async ({ request }) => {
  const { session } = await authenticate.admin(request);
  const layoutStatuses = await getAllLayoutStatuses(session);
  return json({ layoutStatuses });
};
function Dashboard() {
  const { layoutStatuses } = useLoaderData();
  const activeLayouts = Object.entries(layoutStatuses).filter(([, status]) => status === "active").map(([layout]) => layout);
  return /* @__PURE__ */ jsxs(Page, { children: [
    /* @__PURE__ */ jsx("ui-title-bar", { title: "Dashboard", children: /* @__PURE__ */ jsx(Link, { to: "/app", children: "Back to Section Store" }) }),
    /* @__PURE__ */ jsx(Layout, { children: /* @__PURE__ */ jsx(Layout.Section, { children: /* @__PURE__ */ jsxs(Card, { children: [
      /* @__PURE__ */ jsx(Text, { as: "h2", variant: "headingLg", children: "Active Layouts" }),
      activeLayouts.length > 0 ? /* @__PURE__ */ jsx("ul", { children: activeLayouts.map((layout) => /* @__PURE__ */ jsx("li", { children: layout }, layout)) }) : /* @__PURE__ */ jsx(Text, { children: "No active layouts" })
    ] }) }) })
  ] });
}
const route1 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: Dashboard,
  loader: loader$7
}, Symbol.toStringTag, { value: "Module" }));
const loader$6 = async ({ request }) => {
  const { session } = await authenticate.admin(request);
  const url = new URL(request.url);
  const chargeId = url.searchParams.get("charge_id");
  let chargeStatus = null;
  if (chargeId) {
    const chargeGid = `gid://shopify/AppPurchaseOneTime/${chargeId}`;
    chargeStatus = await updateChargeStatus(session, chargeGid);
  }
  const layout1Status = await getLayoutStatus(session, "Layout 1");
  const layout2Status = await getLayoutStatus(session, "Layout 2");
  const layout3Status = await getLayoutStatus(session, "Layout 3");
  const layout4Status = await getLayoutStatus(session, "Layout 4");
  return json({
    layout1Status,
    layout2Status,
    layout3Status,
    layout4Status,
    chargeStatus
    // Include charge status in response
  });
};
const action$2 = async ({ request }) => {
  const { session } = await authenticate.admin(request);
  const formData = await request.formData();
  const action2 = formData.get("action");
  const layout = formData.get("layout");
  const { shop } = session;
  console.log(`Received action: ${action2} for layout: ${layout}`);
  let result;
  const url = new URL(request.url);
  const chargeId = url.searchParams.get("charge_id");
  if (chargeId) {
    const chargeGid = `gid://shopify/AppPurchaseOneTime/${chargeId}`;
    const chargeStatus = await updateChargeStatus(session, chargeGid);
    console.log("Charge status updated:", chargeStatus);
    return json({ success: true, chargeStatus });
  }
  switch (action2) {
    case "activate":
      result = await handleActivation(session, layout, shop);
      if (result.success && result.confirmationUrl) {
        return json(result);
      }
      break;
    case "deactivate":
      result = await handleDeactivation(session, layout);
      break;
    default:
      return json({ success: false, message: "Invalid action" }, { status: 400 });
  }
  console.log("Action result:", result);
  return json(result);
};
async function handleActivation(session, layout, shop) {
  let chargeData;
  switch (layout) {
    case "Layout 1":
      chargeData = { name: layout, price: { amount: 50, currencyCode: "INR" }, test: true };
      break;
    case "Layout 2":
      return await activateFreeLayout(session, layout);
    case "Layout 3":
      return await activateFreeLayout(session, layout);
    case "Layout 4":
      return await activateFreeLayout(session, layout);
    default:
      return { success: false, message: "Invalid layout" };
  }
  if (chargeData) {
    try {
      console.log(chargeData);
      const confirmationUrl = await createOneTimeCharge(session, chargeData.name, chargeData.price, `https://${shop}/admin/apps/section-store-11/app`);
      return { success: true, confirmationUrl };
    } catch (error) {
      console.error("Error creating one-time charge:", error);
      return { success: false, message: "Error creating charge" };
    }
  }
}
async function handleDeactivation(session, layout) {
  try {
    await deactivateLayout(session, layout);
    return { success: true, message: `${layout} deactivated successfully` };
  } catch (error) {
    console.error("Error deactivating layout:", error);
    return { success: false, message: "Error deactivating layout" };
  }
}
function Index() {
  const {
    layout1Status,
    layout2Status,
    layout3Status,
    layout4Status,
    chargeStatus
  } = useLoaderData();
  const fetcher = useFetcher();
  const navigate = useNavigate();
  useEffect(() => {
    if (chargeStatus) {
      if (chargeStatus.success) {
        alert(chargeStatus.message);
        navigate("/app", { replace: true });
      } else {
        alert(chargeStatus.message || "Payment verification failed");
      }
    }
  }, [chargeStatus, navigate]);
  const handleAction = useCallback((layout, action2) => {
    console.log(`Handling action: ${action2} for layout: ${layout}`);
    fetcher.submit({ action: action2, layout }, { method: "post" });
  }, [fetcher]);
  useEffect(() => {
    if (fetcher.data) {
      console.log("Fetcher data:", fetcher.data);
      if (fetcher.data.success) {
        if (fetcher.data.confirmationUrl) {
          window.open(fetcher.data.confirmationUrl, "_blank");
        } else if (fetcher.data.message) {
          alert(fetcher.data.message);
          window.location.reload();
        }
      } else {
        console.error(fetcher.data.message);
        alert(fetcher.data.message || "An error occurred. Please try again.");
      }
    }
  }, [fetcher.data]);
  const renderLayoutCard = (title, status, activatePrice, layout) => /* @__PURE__ */ jsx(Layout.Section, { variant: "oneThird", children: /* @__PURE__ */ jsxs(Card, { children: [
    /* @__PURE__ */ jsx(Text, { as: "h2", variant: "headingMd", children: title }),
    /* @__PURE__ */ jsx(
      "img",
      {
        src: `/images/${title.toLowerCase().replace(/\s+/g, "-")}.png`,
        alt: `${title} Image`,
        style: { width: "100%", height: "auto" }
      }
    ),
    /* @__PURE__ */ jsx("div", { style: { height: "15px" } }),
    /* @__PURE__ */ jsxs(BlockStack, { gap: "300", children: [
      /* @__PURE__ */ jsx(Text, { children: status === "active" ? `${title} is active` : `${title} is inactive` }),
      status === "active" ? /* @__PURE__ */ jsx(Button, { onClick: () => handleAction(title, "deactivate"), variant: "primary", children: "Deactivate" }) : /* @__PURE__ */ jsx(Button, { onClick: () => handleAction(title, "activate"), variant: "primary", children: activatePrice ? `Buy ₹${activatePrice}` : "Get Free" })
    ] })
  ] }) });
  return /* @__PURE__ */ jsxs(Page, { children: [
    /* @__PURE__ */ jsx("ui-title-bar", { title: "Section Store", children: /* @__PURE__ */ jsx(Link, { to: "/app/dashboard", children: "View Dashboard" }) }),
    /* @__PURE__ */ jsx(BlockStack, { gap: "500", children: /* @__PURE__ */ jsxs(Layout, { children: [
      renderLayoutCard("Layout 1", layout1Status, 50),
      renderLayoutCard("Layout 2", layout2Status, null),
      renderLayoutCard("Layout 3", layout3Status, null),
      renderLayoutCard("Layout 4", layout4Status, null)
    ] }) })
  ] });
}
const route2 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action: action$2,
  default: Index,
  loader: loader$6
}, Symbol.toStringTag, { value: "Module" }));
const Polaris = {
  ActionMenu: {
    Actions: {
      moreActions: "More actions"
    },
    RollupActions: {
      rollupButton: "View actions"
    }
  },
  ActionList: {
    SearchField: {
      clearButtonLabel: "Clear",
      search: "Search",
      placeholder: "Search actions"
    }
  },
  Avatar: {
    label: "Avatar",
    labelWithInitials: "Avatar with initials {initials}"
  },
  Autocomplete: {
    spinnerAccessibilityLabel: "Loading",
    ellipsis: "{content}…"
  },
  Badge: {
    PROGRESS_LABELS: {
      incomplete: "Incomplete",
      partiallyComplete: "Partially complete",
      complete: "Complete"
    },
    TONE_LABELS: {
      info: "Info",
      success: "Success",
      warning: "Warning",
      critical: "Critical",
      attention: "Attention",
      "new": "New",
      readOnly: "Read-only",
      enabled: "Enabled"
    },
    progressAndTone: "{toneLabel} {progressLabel}"
  },
  Banner: {
    dismissButton: "Dismiss notification"
  },
  Button: {
    spinnerAccessibilityLabel: "Loading"
  },
  Common: {
    checkbox: "checkbox",
    undo: "Undo",
    cancel: "Cancel",
    clear: "Clear",
    close: "Close",
    submit: "Submit",
    more: "More"
  },
  ContextualSaveBar: {
    save: "Save",
    discard: "Discard"
  },
  DataTable: {
    sortAccessibilityLabel: "sort {direction} by",
    navAccessibilityLabel: "Scroll table {direction} one column",
    totalsRowHeading: "Totals",
    totalRowHeading: "Total"
  },
  DatePicker: {
    previousMonth: "Show previous month, {previousMonthName} {showPreviousYear}",
    nextMonth: "Show next month, {nextMonth} {nextYear}",
    today: "Today ",
    start: "Start of range",
    end: "End of range",
    months: {
      january: "January",
      february: "February",
      march: "March",
      april: "April",
      may: "May",
      june: "June",
      july: "July",
      august: "August",
      september: "September",
      october: "October",
      november: "November",
      december: "December"
    },
    days: {
      monday: "Monday",
      tuesday: "Tuesday",
      wednesday: "Wednesday",
      thursday: "Thursday",
      friday: "Friday",
      saturday: "Saturday",
      sunday: "Sunday"
    },
    daysAbbreviated: {
      monday: "Mo",
      tuesday: "Tu",
      wednesday: "We",
      thursday: "Th",
      friday: "Fr",
      saturday: "Sa",
      sunday: "Su"
    }
  },
  DiscardConfirmationModal: {
    title: "Discard all unsaved changes",
    message: "If you discard changes, you’ll delete any edits you made since you last saved.",
    primaryAction: "Discard changes",
    secondaryAction: "Continue editing"
  },
  DropZone: {
    single: {
      overlayTextFile: "Drop file to upload",
      overlayTextImage: "Drop image to upload",
      overlayTextVideo: "Drop video to upload",
      actionTitleFile: "Add file",
      actionTitleImage: "Add image",
      actionTitleVideo: "Add video",
      actionHintFile: "or drop file to upload",
      actionHintImage: "or drop image to upload",
      actionHintVideo: "or drop video to upload",
      labelFile: "Upload file",
      labelImage: "Upload image",
      labelVideo: "Upload video"
    },
    allowMultiple: {
      overlayTextFile: "Drop files to upload",
      overlayTextImage: "Drop images to upload",
      overlayTextVideo: "Drop videos to upload",
      actionTitleFile: "Add files",
      actionTitleImage: "Add images",
      actionTitleVideo: "Add videos",
      actionHintFile: "or drop files to upload",
      actionHintImage: "or drop images to upload",
      actionHintVideo: "or drop videos to upload",
      labelFile: "Upload files",
      labelImage: "Upload images",
      labelVideo: "Upload videos"
    },
    errorOverlayTextFile: "File type is not valid",
    errorOverlayTextImage: "Image type is not valid",
    errorOverlayTextVideo: "Video type is not valid"
  },
  EmptySearchResult: {
    altText: "Empty search results"
  },
  Frame: {
    skipToContent: "Skip to content",
    navigationLabel: "Navigation",
    Navigation: {
      closeMobileNavigationLabel: "Close navigation"
    }
  },
  FullscreenBar: {
    back: "Back",
    accessibilityLabel: "Exit fullscreen mode"
  },
  Filters: {
    moreFilters: "More filters",
    moreFiltersWithCount: "More filters ({count})",
    filter: "Filter {resourceName}",
    noFiltersApplied: "No filters applied",
    cancel: "Cancel",
    done: "Done",
    clearAllFilters: "Clear all filters",
    clear: "Clear",
    clearLabel: "Clear {filterName}",
    addFilter: "Add filter",
    clearFilters: "Clear all",
    searchInView: "in:{viewName}"
  },
  FilterPill: {
    clear: "Clear",
    unsavedChanges: "Unsaved changes - {label}"
  },
  IndexFilters: {
    searchFilterTooltip: "Search and filter",
    searchFilterTooltipWithShortcut: "Search and filter (F)",
    searchFilterAccessibilityLabel: "Search and filter results",
    sort: "Sort your results",
    addView: "Add a new view",
    newView: "Custom search",
    SortButton: {
      ariaLabel: "Sort the results",
      tooltip: "Sort",
      title: "Sort by",
      sorting: {
        asc: "Ascending",
        desc: "Descending",
        az: "A-Z",
        za: "Z-A"
      }
    },
    EditColumnsButton: {
      tooltip: "Edit columns",
      accessibilityLabel: "Customize table column order and visibility"
    },
    UpdateButtons: {
      cancel: "Cancel",
      update: "Update",
      save: "Save",
      saveAs: "Save as",
      modal: {
        title: "Save view as",
        label: "Name",
        sameName: "A view with this name already exists. Please choose a different name.",
        save: "Save",
        cancel: "Cancel"
      }
    }
  },
  IndexProvider: {
    defaultItemSingular: "Item",
    defaultItemPlural: "Items",
    allItemsSelected: "All {itemsLength}+ {resourceNamePlural} are selected",
    selected: "{selectedItemsCount} selected",
    a11yCheckboxDeselectAllSingle: "Deselect {resourceNameSingular}",
    a11yCheckboxSelectAllSingle: "Select {resourceNameSingular}",
    a11yCheckboxDeselectAllMultiple: "Deselect all {itemsLength} {resourceNamePlural}",
    a11yCheckboxSelectAllMultiple: "Select all {itemsLength} {resourceNamePlural}"
  },
  IndexTable: {
    emptySearchTitle: "No {resourceNamePlural} found",
    emptySearchDescription: "Try changing the filters or search term",
    onboardingBadgeText: "New",
    resourceLoadingAccessibilityLabel: "Loading {resourceNamePlural}…",
    selectAllLabel: "Select all {resourceNamePlural}",
    selected: "{selectedItemsCount} selected",
    undo: "Undo",
    selectAllItems: "Select all {itemsLength}+ {resourceNamePlural}",
    selectItem: "Select {resourceName}",
    selectButtonText: "Select",
    sortAccessibilityLabel: "sort {direction} by"
  },
  Loading: {
    label: "Page loading bar"
  },
  Modal: {
    iFrameTitle: "body markup",
    modalWarning: "These required properties are missing from Modal: {missingProps}"
  },
  Page: {
    Header: {
      rollupActionsLabel: "View actions for {title}",
      pageReadyAccessibilityLabel: "{title}. This page is ready"
    }
  },
  Pagination: {
    previous: "Previous",
    next: "Next",
    pagination: "Pagination"
  },
  ProgressBar: {
    negativeWarningMessage: "Values passed to the progress prop shouldn’t be negative. Resetting {progress} to 0.",
    exceedWarningMessage: "Values passed to the progress prop shouldn’t exceed 100. Setting {progress} to 100."
  },
  ResourceList: {
    sortingLabel: "Sort by",
    defaultItemSingular: "item",
    defaultItemPlural: "items",
    showing: "Showing {itemsCount} {resource}",
    showingTotalCount: "Showing {itemsCount} of {totalItemsCount} {resource}",
    loading: "Loading {resource}",
    selected: "{selectedItemsCount} selected",
    allItemsSelected: "All {itemsLength}+ {resourceNamePlural} in your store are selected",
    allFilteredItemsSelected: "All {itemsLength}+ {resourceNamePlural} in this filter are selected",
    selectAllItems: "Select all {itemsLength}+ {resourceNamePlural} in your store",
    selectAllFilteredItems: "Select all {itemsLength}+ {resourceNamePlural} in this filter",
    emptySearchResultTitle: "No {resourceNamePlural} found",
    emptySearchResultDescription: "Try changing the filters or search term",
    selectButtonText: "Select",
    a11yCheckboxDeselectAllSingle: "Deselect {resourceNameSingular}",
    a11yCheckboxSelectAllSingle: "Select {resourceNameSingular}",
    a11yCheckboxDeselectAllMultiple: "Deselect all {itemsLength} {resourceNamePlural}",
    a11yCheckboxSelectAllMultiple: "Select all {itemsLength} {resourceNamePlural}",
    Item: {
      actionsDropdownLabel: "Actions for {accessibilityLabel}",
      actionsDropdown: "Actions dropdown",
      viewItem: "View details for {itemName}"
    },
    BulkActions: {
      actionsActivatorLabel: "Actions",
      moreActionsActivatorLabel: "More actions"
    }
  },
  SkeletonPage: {
    loadingLabel: "Page loading"
  },
  Tabs: {
    newViewAccessibilityLabel: "Create new view",
    newViewTooltip: "Create view",
    toggleTabsLabel: "More views",
    Tab: {
      rename: "Rename view",
      duplicate: "Duplicate view",
      edit: "Edit view",
      editColumns: "Edit columns",
      "delete": "Delete view",
      copy: "Copy of {name}",
      deleteModal: {
        title: "Delete view?",
        description: "This can’t be undone. {viewName} view will no longer be available in your admin.",
        cancel: "Cancel",
        "delete": "Delete view"
      }
    },
    RenameModal: {
      title: "Rename view",
      label: "Name",
      cancel: "Cancel",
      create: "Save",
      errors: {
        sameName: "A view with this name already exists. Please choose a different name."
      }
    },
    DuplicateModal: {
      title: "Duplicate view",
      label: "Name",
      cancel: "Cancel",
      create: "Create view",
      errors: {
        sameName: "A view with this name already exists. Please choose a different name."
      }
    },
    CreateViewModal: {
      title: "Create new view",
      label: "Name",
      cancel: "Cancel",
      create: "Create view",
      errors: {
        sameName: "A view with this name already exists. Please choose a different name."
      }
    }
  },
  Tag: {
    ariaLabel: "Remove {children}"
  },
  TextField: {
    characterCount: "{count} characters",
    characterCountWithMaxLength: "{count} of {limit} characters used"
  },
  TooltipOverlay: {
    accessibilityLabel: "Tooltip: {label}"
  },
  TopBar: {
    toggleMenuLabel: "Toggle menu",
    SearchField: {
      clearButtonLabel: "Clear",
      search: "Search"
    }
  },
  MediaCard: {
    dismissButton: "Dismiss",
    popoverButton: "Actions"
  },
  VideoThumbnail: {
    playButtonA11yLabel: {
      "default": "Play video",
      defaultWithDuration: "Play video of length {duration}",
      duration: {
        hours: {
          other: {
            only: "{hourCount} hours",
            andMinutes: "{hourCount} hours and {minuteCount} minutes",
            andMinute: "{hourCount} hours and {minuteCount} minute",
            minutesAndSeconds: "{hourCount} hours, {minuteCount} minutes, and {secondCount} seconds",
            minutesAndSecond: "{hourCount} hours, {minuteCount} minutes, and {secondCount} second",
            minuteAndSeconds: "{hourCount} hours, {minuteCount} minute, and {secondCount} seconds",
            minuteAndSecond: "{hourCount} hours, {minuteCount} minute, and {secondCount} second",
            andSeconds: "{hourCount} hours and {secondCount} seconds",
            andSecond: "{hourCount} hours and {secondCount} second"
          },
          one: {
            only: "{hourCount} hour",
            andMinutes: "{hourCount} hour and {minuteCount} minutes",
            andMinute: "{hourCount} hour and {minuteCount} minute",
            minutesAndSeconds: "{hourCount} hour, {minuteCount} minutes, and {secondCount} seconds",
            minutesAndSecond: "{hourCount} hour, {minuteCount} minutes, and {secondCount} second",
            minuteAndSeconds: "{hourCount} hour, {minuteCount} minute, and {secondCount} seconds",
            minuteAndSecond: "{hourCount} hour, {minuteCount} minute, and {secondCount} second",
            andSeconds: "{hourCount} hour and {secondCount} seconds",
            andSecond: "{hourCount} hour and {secondCount} second"
          }
        },
        minutes: {
          other: {
            only: "{minuteCount} minutes",
            andSeconds: "{minuteCount} minutes and {secondCount} seconds",
            andSecond: "{minuteCount} minutes and {secondCount} second"
          },
          one: {
            only: "{minuteCount} minute",
            andSeconds: "{minuteCount} minute and {secondCount} seconds",
            andSecond: "{minuteCount} minute and {secondCount} second"
          }
        },
        seconds: {
          other: "{secondCount} seconds",
          one: "{secondCount} second"
        }
      }
    }
  }
};
const polarisTranslations = {
  Polaris
};
function loginErrorMessage(loginErrors) {
  if ((loginErrors == null ? void 0 : loginErrors.shop) === LoginErrorType.MissingShop) {
    return { shop: "Please enter your shop domain to log in" };
  } else if ((loginErrors == null ? void 0 : loginErrors.shop) === LoginErrorType.InvalidShop) {
    return { shop: "Please enter a valid shop domain to log in" };
  }
  return {};
}
const loader$5 = async ({ request }) => {
  const errors = loginErrorMessage(await login(request));
  return json({ errors, polarisTranslations });
};
const action$1 = async ({ request }) => {
  const errors = loginErrorMessage(await login(request));
  return json({
    errors
  });
};
function Auth() {
  const loaderData = useLoaderData();
  const actionData = useActionData();
  const [shop, setShop] = useState("");
  const { errors } = actionData || loaderData;
  return /* @__PURE__ */ jsx(AppProvider, { i18n: loaderData.polarisTranslations, children: /* @__PURE__ */ jsx(Page, { children: /* @__PURE__ */ jsx(Card, { children: /* @__PURE__ */ jsx(Form, { method: "post", children: /* @__PURE__ */ jsxs(FormLayout, { children: [
    /* @__PURE__ */ jsx(Text, { variant: "headingMd", as: "h2", children: "Log in" }),
    /* @__PURE__ */ jsx(
      TextField,
      {
        type: "text",
        name: "shop",
        label: "Shop domain",
        helpText: "example.myshopify.com",
        value: shop,
        onChange: setShop,
        autoComplete: "on",
        error: errors.shop
      }
    ),
    /* @__PURE__ */ jsx(Button, { submit: true, children: "Log in" })
  ] }) }) }) }) });
}
const route3 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action: action$1,
  default: Auth,
  loader: loader$5
}, Symbol.toStringTag, { value: "Module" }));
const action = async ({ request }) => {
  const { topic, shop, session, admin, payload } = await authenticate.webhook(request);
  if (!admin) {
    throw new Response();
  }
  switch (topic) {
    case "APP_UNINSTALLED":
      if (session) {
        await prisma.session.deleteMany({ where: { shop } });
      }
      break;
    case "APP_PURCHASES_ONE_TIME_UPDATE":
      await handleAppPurchaseWebhook(request);
      return new Response(null, { status: 200 });
    case "CUSTOMERS_DATA_REQUEST":
    case "CUSTOMERS_REDACT":
    case "SHOP_REDACT":
    default:
      throw new Response("Unhandled webhook topic", { status: 404 });
  }
  return new Response(null, { status: 200 });
};
const route4 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action
}, Symbol.toStringTag, { value: "Module" }));
const loader$4 = async ({ request }) => {
  return { pageName: "Explore" };
};
function SettingsPage() {
  const { pageName } = useLoaderData();
  return /* @__PURE__ */ jsxs("div", { children: [
    /* @__PURE__ */ jsx("h1", { children: pageName }),
    /* @__PURE__ */ jsx("p", { children: "Welcome to the Settings page!" })
  ] });
}
const route5 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: SettingsPage,
  loader: loader$4
}, Symbol.toStringTag, { value: "Module" }));
const loader$3 = async ({ request }) => {
  await authenticate.admin(request);
  return null;
};
const route6 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  loader: loader$3
}, Symbol.toStringTag, { value: "Module" }));
async function loader$2({ request }) {
  try {
    const url = new URL(request.url);
    const storeName = url.searchParams.get("shop") || url.hostname.split(".")[0];
    if (!storeName) {
      console.log("Store name not found in URL");
      return json({ activeLayouts: [], error: "Store name not found" }, { status: 400 });
    }
    const result = await query(
      "SELECT layout_name FROM layouts WHERE shop = ? AND status = 'active'",
      [storeName]
    );
    const activeLayouts = result.map((row) => row.layout_name);
    return json({ activeLayouts });
  } catch (error) {
    console.error("Error in layout loader:", error);
    return json({ activeLayouts: [], error: "Internal server error" }, { status: 500 });
  }
}
const route7 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  loader: loader$2
}, Symbol.toStringTag, { value: "Module" }));
const index = "_index_1hqgz_1";
const heading = "_heading_1hqgz_21";
const text = "_text_1hqgz_23";
const content = "_content_1hqgz_43";
const form = "_form_1hqgz_53";
const label = "_label_1hqgz_69";
const input = "_input_1hqgz_85";
const button = "_button_1hqgz_93";
const list = "_list_1hqgz_101";
const styles = {
  index,
  heading,
  text,
  content,
  form,
  label,
  input,
  button,
  list
};
const loader$1 = async ({ request }) => {
  const url = new URL(request.url);
  if (url.searchParams.get("shop")) {
    throw redirect(`/app?${url.searchParams.toString()}`);
  }
  return json({ showForm: Boolean(login) });
};
function App$1() {
  const { showForm } = useLoaderData();
  return /* @__PURE__ */ jsx("div", { className: styles.index, children: /* @__PURE__ */ jsxs("div", { className: styles.content, children: [
    /* @__PURE__ */ jsx("h1", { className: styles.heading, children: "A short heading about [your app]" }),
    /* @__PURE__ */ jsx("p", { className: styles.text, children: "A tagline about [your app] that describes your value proposition." }),
    showForm && /* @__PURE__ */ jsxs(Form, { className: styles.form, method: "post", action: "/auth/login", children: [
      /* @__PURE__ */ jsxs("label", { className: styles.label, children: [
        /* @__PURE__ */ jsx("span", { children: "Shop domain" }),
        /* @__PURE__ */ jsx("input", { className: styles.input, type: "text", name: "shop" }),
        /* @__PURE__ */ jsx("span", { children: "e.g: my-shop-domain.myshopify.com" })
      ] }),
      /* @__PURE__ */ jsx("button", { className: styles.button, type: "submit", children: "Log in" })
    ] }),
    /* @__PURE__ */ jsxs("ul", { className: styles.list, children: [
      /* @__PURE__ */ jsxs("li", { children: [
        /* @__PURE__ */ jsx("strong", { children: "Product feature" }),
        ". Some detail about your feature and its benefit to your customer."
      ] }),
      /* @__PURE__ */ jsxs("li", { children: [
        /* @__PURE__ */ jsx("strong", { children: "Product feature" }),
        ". Some detail about your feature and its benefit to your customer."
      ] }),
      /* @__PURE__ */ jsxs("li", { children: [
        /* @__PURE__ */ jsx("strong", { children: "Product feature" }),
        ". Some detail about your feature and its benefit to your customer."
      ] })
    ] })
  ] }) });
}
const route8 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: App$1,
  loader: loader$1
}, Symbol.toStringTag, { value: "Module" }));
const loader = async ({ request }) => {
  await authenticate.admin(request);
  return json({ apiKey: process.env.SHOPIFY_API_KEY || "" });
};
function App() {
  const { apiKey } = useLoaderData();
  return /* @__PURE__ */ jsxs(AppProvider$1, { isEmbeddedApp: true, apiKey, children: [
    /* @__PURE__ */ jsx("ui-nav-menu", { children: /* @__PURE__ */ jsx(Link, { to: "/app", rel: "home", children: "Home" }) }),
    /* @__PURE__ */ jsx(Outlet, {})
  ] });
}
function ErrorBoundary() {
  return boundary.error(useRouteError());
}
const headers = (headersArgs) => {
  return boundary.headers(headersArgs);
};
const route9 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  ErrorBoundary,
  default: App,
  headers,
  loader
}, Symbol.toStringTag, { value: "Module" }));
const serverManifest = { "entry": { "module": "/assets/entry.client-Bob-nhgV.js", "imports": ["/assets/components-DCFC9nqj.js"], "css": [] }, "routes": { "root": { "id": "root", "parentId": void 0, "path": "", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": false, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/root-BjzBpRZt.js", "imports": ["/assets/components-DCFC9nqj.js"], "css": [] }, "routes/app.dashboard": { "id": "routes/app.dashboard", "parentId": "routes/app", "path": "dashboard", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/app.dashboard-DVD3qN7t.js", "imports": ["/assets/components-DCFC9nqj.js", "/assets/context-C4QYp43w.js", "/assets/Page-CQ8qt5e1.js", "/assets/Layout-5NHH-Pux.js"], "css": [] }, "routes/app._index": { "id": "routes/app._index", "parentId": "routes/app", "path": void 0, "index": true, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/app._index-DVLQ6m8u.js", "imports": ["/assets/components-DCFC9nqj.js", "/assets/context-C4QYp43w.js", "/assets/Page-CQ8qt5e1.js", "/assets/Layout-5NHH-Pux.js"], "css": [] }, "routes/auth.login": { "id": "routes/auth.login", "parentId": "root", "path": "auth/login", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/route-IzeBZrQB.js", "imports": ["/assets/components-DCFC9nqj.js", "/assets/context-C4QYp43w.js", "/assets/styles-DPFRU_8p.js", "/assets/Page-CQ8qt5e1.js"], "css": ["/assets/styles-DT9i95_b.css"] }, "routes/webhooks": { "id": "routes/webhooks", "parentId": "root", "path": "webhooks", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": false, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/webhooks-l0sNRNKZ.js", "imports": [], "css": [] }, "routes/explore": { "id": "routes/explore", "parentId": "root", "path": "explore", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/explore-CDX9IuYm.js", "imports": ["/assets/components-DCFC9nqj.js"], "css": [] }, "routes/auth.$": { "id": "routes/auth.$", "parentId": "root", "path": "auth/*", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/auth._-l0sNRNKZ.js", "imports": [], "css": [] }, "routes/layout": { "id": "routes/layout", "parentId": "root", "path": "layout", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/layout-l0sNRNKZ.js", "imports": [], "css": [] }, "routes/_index": { "id": "routes/_index", "parentId": "root", "path": void 0, "index": true, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/assets/route-Bi8BsP4j.js", "imports": ["/assets/components-DCFC9nqj.js"], "css": ["/assets/route-Qq2qOeDq.css"] }, "routes/app": { "id": "routes/app", "parentId": "root", "path": "app", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": true, "module": "/assets/app-zSJXm1EA.js", "imports": ["/assets/components-DCFC9nqj.js", "/assets/context-C4QYp43w.js", "/assets/styles-DPFRU_8p.js"], "css": ["/assets/styles-DT9i95_b.css"] } }, "url": "/assets/manifest-245fd69f.js", "version": "245fd69f" };
const mode = "production";
const assetsBuildDirectory = "build\\client";
const basename = "/";
const future = { "v3_fetcherPersist": false, "v3_relativeSplatPath": false, "v3_throwAbortReason": false, "unstable_singleFetch": false };
const isSpaMode = false;
const publicPath = "/";
const entry = { module: entryServer };
const routes = {
  "root": {
    id: "root",
    parentId: void 0,
    path: "",
    index: void 0,
    caseSensitive: void 0,
    module: route0
  },
  "routes/app.dashboard": {
    id: "routes/app.dashboard",
    parentId: "routes/app",
    path: "dashboard",
    index: void 0,
    caseSensitive: void 0,
    module: route1
  },
  "routes/app._index": {
    id: "routes/app._index",
    parentId: "routes/app",
    path: void 0,
    index: true,
    caseSensitive: void 0,
    module: route2
  },
  "routes/auth.login": {
    id: "routes/auth.login",
    parentId: "root",
    path: "auth/login",
    index: void 0,
    caseSensitive: void 0,
    module: route3
  },
  "routes/webhooks": {
    id: "routes/webhooks",
    parentId: "root",
    path: "webhooks",
    index: void 0,
    caseSensitive: void 0,
    module: route4
  },
  "routes/explore": {
    id: "routes/explore",
    parentId: "root",
    path: "explore",
    index: void 0,
    caseSensitive: void 0,
    module: route5
  },
  "routes/auth.$": {
    id: "routes/auth.$",
    parentId: "root",
    path: "auth/*",
    index: void 0,
    caseSensitive: void 0,
    module: route6
  },
  "routes/layout": {
    id: "routes/layout",
    parentId: "root",
    path: "layout",
    index: void 0,
    caseSensitive: void 0,
    module: route7
  },
  "routes/_index": {
    id: "routes/_index",
    parentId: "root",
    path: void 0,
    index: true,
    caseSensitive: void 0,
    module: route8
  },
  "routes/app": {
    id: "routes/app",
    parentId: "root",
    path: "app",
    index: void 0,
    caseSensitive: void 0,
    module: route9
  }
};
export {
  serverManifest as assets,
  assetsBuildDirectory,
  basename,
  entry,
  future,
  isSpaMode,
  mode,
  publicPath,
  routes
};
